/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.adaptive.media.upload.internal.web.attachment;

import com.liferay.adaptive.media.image.html.constants.AMImageHTMLConstants;
import com.liferay.portal.kernel.repository.model.FileEntry;
import com.liferay.upload.AttachmentElementReplacer;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alejandro Tardín
 */
@Component(
	property = {
		"format=html", "html.tag.name=img", "service.ranking:Integer=2"
	},
	service = AttachmentElementReplacer.class
)
public class AMHTMLImageAttachmentElementReplacer
	implements AttachmentElementReplacer {

	public AMHTMLImageAttachmentElementReplacer() {
	}

	@Override
	public String replace(String originalElement, FileEntry fileEntry) {
		Element imageElement = _parseImgTag(
			_defaultAttachmentElementReplacer.replace(
				originalElement, fileEntry));

		imageElement.attr(
			AMImageHTMLConstants.ATTRIBUTE_NAME_FILE_ENTRY_ID,
			String.valueOf(fileEntry.getFileEntryId()));

		return imageElement.toString();
	}

	protected AMHTMLImageAttachmentElementReplacer(
		AttachmentElementReplacer defaultAttachmentElementReplacer) {

		_defaultAttachmentElementReplacer = defaultAttachmentElementReplacer;
	}

	private Element _parseImgTag(String originalImgTag) {
		Document document = Jsoup.parseBodyFragment(originalImgTag);

		Document.OutputSettings outputSettings = new Document.OutputSettings();

		outputSettings.prettyPrint(false);
		outputSettings.syntax(Document.OutputSettings.Syntax.xml);

		document.outputSettings(outputSettings);

		Element element = document.body();

		return element.child(0);
	}

	@Reference(
		target = "(&(format=html)(html.tag.name=img)(!(component.name=com.liferay.adaptive.media.upload.internal.web.attachment.AMHTMLImageAttachmentElementReplacer)))"
	)
	private AttachmentElementReplacer _defaultAttachmentElementReplacer;

}